@@ -16,6 +16,7 @@
 
 import configparser
 from pathlib import Path
+import pickle
 from typing import List
 from typing import Optional
 from typing import Tuple
@@ -167,9 +168,9 @@ def _get_dataframe_query(db: Database,
     return df
 
 
-def get_dataframe(db: Database,
-                  ids: Optional[Union[int, List[int], Tuple[int, ...]]] = None,
-                  include_artifacts: bool = False) -> pd.DataFrame:
+def _get_dataframe(db: Database,
+                   ids: Optional[Union[int, List[int], Tuple[int, ...]]] = None,
+                   include_artifacts: bool = False) -> pd.DataFrame:
     """Get all experiments from a Sacred Database in a DataFrame.
     Metrics and configurations are concatenated into a single DataFrame for
     convenience.
@@ -187,7 +188,7 @@ def get_dataframe(db: Database,
         DataFrame of the corresponding Database.
     """
     # Wrap ids into list
-    ids = _wrap_ids(ids)
+    ids = _wrap_ids(ids) if ids is not None else ids
 
     # Get all metric and run logs
     query = {} if ids is None else {"run_id": {"$in": ids}}
@@ -213,7 +214,7 @@ def get_dataframe(db: Database,
     df_runs = pd.concat([df_runs, tmp], axis=1)
 
     # Get all IDs
-    ids = df_runs['_id'].unique().tolist()
+    id_list = df_runs['_id'].unique().tolist()
 
     # Get metric column names
     metrics = df_metric['name'].unique().tolist()
@@ -221,7 +222,7 @@ def get_dataframe(db: Database,
 
     # Create new DatFrame with extracted metrics
     df_metrics_full = pd.DataFrame(columns=["_id", *cols])
-    for id in ids:
+    for id in id_list:
         df_metrics_full = df_metrics_full.append(pd.DataFrame([[id]], columns=['_id']))
         df_metrics_full.index = df_metrics_full['_id'].tolist()
         for col in metrics:
@@ -256,9 +257,92 @@ def get_dataframe(db: Database,
 
     df = df_runs.join(df_metrics_full)
     df = df.rename(columns={'_id': 'id'})
+
     return df
 
 
+def _get_dataframe_cached(db: Database,
+                          ids: Optional[Union[int, List[int], Tuple[int, ...]]] = None,
+                          include_artifacts: bool = False,
+                          verify: bool = False,
+                          force: bool = False) -> pd.DataFrame:
+    """Retrieve dataframe from MongoDB and cache result.
+
+    Caution: When retrieving the full database (using `ids = None`), by default
+    it is not verified that the local version is up-to-date with the remote
+    version. To verify and possibly re-download the up-to-date database,
+    use `verify=True`.
+
+    Args:
+        db: DataBase instance.
+
+        ids: Optional list of run IDs to get. If None, all IDs are queried.
+
+        include_artifacts: Whether to include a column for artifacts.
+                           Artifacts can then be resolved via
+                           :func:resolve_artifacts().
+
+        verify: Whether to verify that local version is up-to-date with remote
+                database. Only used when `ids=None`.
+
+        force: Whether to force re-loading from MongoDB, even if cached
+               version is available.
+
+    Returns:
+        DataFrame of the corresponding Database.
+    """
+
+    filename = f"{db.name}_ids_{ids}_artifacts_{include_artifacts}.pickle"
+    get_data = lambda: pickle.dumps(_get_dataframe(db, ids, include_artifacts), protocol=4)
+    path = caching.get(filename, get_data, force)
+
+    df_local = pd.read_pickle(path)
+
+    if ids is None and verify and not force:
+        print("Verifying local version.")
+        ids_local = df_local['id'].tolist()
+        ids_remote = _get_dataframe_query(db, {}, "runs")['_id'].tolist()
+        if ids_local != ids_remote:
+            print("Remote version has been altered. Re-downloading.")
+            path = caching.get(filename, get_data, force=True)
+            df_local = pd.read_pickle(path)
+
+    return df_local
+
+
+def get_dataframe(db: Database,
+                  ids: Optional[Union[int, List[int], Tuple[int, ...]]] = None,
+                  include_artifacts: bool = False,
+                  cache: bool = False,
+                  **kwargs):
+    """Get all experiments from a Sacred Database in a DataFrame.
+    Metrics and configurations are concatenated into a single DataFrame for
+    convenience.
+
+    Args:
+        db: DataBase instance.
+
+        ids: Optional list of run IDs to get. If None, all IDs are queried.
+
+        include_artifacts: Whether to include a column for artifacts.
+                           Artifacts can then be resolved via
+                           :func:resolve_artifacts().
+
+        cache: Whether to cache the downloaded DataFrame. This can be useful
+               when retrieving very large databases. See :func:`_get_dataframe_cached()`
+               for details and keyword arguments.
+
+        **kwargs: See :func:`_get_dataframe_cached()`.
+
+    Returns:
+        DataFrame of the corresponding Database.
+    """
+    if cache:
+        return _get_dataframe_cached(db, ids, include_artifacts, **kwargs)
+    else:
+        return _get_dataframe(db, ids, include_artifacts)
+
+
 def _get_artifact_content(db: Database, id: Union[str, ObjectId]) -> bytes:
     """Retrieves file content from GridFS by ObjectID. This corresponds to the way sacred saves artifacts.
 
@@ -326,7 +410,7 @@ def get_artifact(db: Database,
         name: Name of artifact to get.
 
         force: Whether to force downloading of the artifact, even if cached
-                version is available.
+               version is available.
 
     Returns:
 
